@@ -86,7 +86,7 @@
 #define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOREADDONS_NO_DEPRECATED
-#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54900
+#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
 #  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x54900
+#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
